# PYTHON-CLI

This is basically your doggy, it helps you to make your programming life easier with profiles that you can manage and shortcuts you can add to certain files or wrokspaces.The profiles consist of various project folder and file extensions that can help you open you workspaces with just on command.